torpedomsg
============================================================

Flexible Pub-Sub on top of Tornado

Installation
------------

The package is published on the `Python index <https://pypi.python.org/pypi/torpedomsg/>`_ simply run the following:

::

    pip install torpedomsg
    
And that's it!

Basic Use
---------

Check examples directory.
